aboutsummaryrefslogtreecommitdiffhomepage
path: root/internal/pkg/net.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/pkg/net.go')
-rw-r--r--internal/pkg/net.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/pkg/net.go b/internal/pkg/net.go
index 1f37a92d..412dd2a7 100644
--- a/internal/pkg/net.go
+++ b/internal/pkg/net.go
@@ -54,8 +54,8 @@ func init() {
})
}
-// Dependencies returns a nil slice.
-func (*httpArtifact) Dependencies() []Artifact { return nil }
+// Inputs returns a nil slice.
+func (*httpArtifact) Inputs() []Artifact { return nil }
// IsExclusive returns false: Cure returns as soon as a response is received.
func (*httpArtifact) IsExclusive() bool { return false }